==> blanco.plugin.charactergroup_0.1.8-src.zip: src/blanco/charactergroup/message/BlancoCharacterGroupMessageResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.charactergroup.message;

import java.text.MessageFormat;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoCharacterGroupMessage/bZ[W`[BlancoCharacterGroup]Iɗp郊\[XohNXB]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 */
class BlancoCharacterGroupMessageResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoCharacterGroupMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoCharacterGroupMessage]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoCharacterGroupMessageResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoCharacterGroupMessage");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoCharacterGroupMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoCharacterGroupMessage]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoCharacterGroupMessageResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoCharacterGroupMessage", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoCharacterGroupMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoCharacterGroupMessage]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoCharacterGroupMessageResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoCharacterGroupMessage", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BlancoCharacterGroupMessage], key[MBCHGI01]
     *
     * [O[v`ID[{0}]̃pbP[Ww肳Ă܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBCHGI01]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbchgi01(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "O[v`ID[{0}]̃pbP[Ww肳Ă܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBCHGI01");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoCharacterGroupMessage], key[MBCHGI02]
     *
     * [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBCHGI02]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbchgi02(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "T|[gȂo̓vO~Oꏈn[{0}]w肳܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBCHGI02");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoCharacterGroupMessage], key[MBCHGI03]
     *
     * [O[v`ID[{0}]ɂāA[{1}]2ȏ゠܂Bl2ȏwł܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBCHGI03]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbchgi03(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "O[v`ID[{0}]ɂāA[{1}]2ȏ゠܂Bl2ȏwł܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBCHGI03");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoCharacterGroupMessage], key[MBCHGI04]
     *
     * [O[v`ID[{0}]ɂāA[{1}]w肳܂B{2}łBO[v`ł́A1Ŏw肷Kv܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @param arg2 u{2}ulBjava.lang.String^^ĂB
     * @return key[MBCHGI04]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbchgi04(final String arg0, final String arg1, final String arg2) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "O[v`ID[{0}]ɂāA[{1}]w肳܂B{2}łBO[v`ł́A1Ŏw肷Kv܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBCHGI04");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1, arg2}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoCharacterGroupMessage], key[MBCHGA01]
     *
     * [^fBNg[{0}]݂܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBCHGA01]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbchga01(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "^fBNg[{0}]݂܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBCHGA01");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }
}

==> blanco.plugin.charactergroup_0.2.1-src.zip: src/blanco/charactergroup/message/BlancoCharacterGroupMessageResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.charactergroup.message;

import java.text.MessageFormat;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoCharacterGroupMessage/bZ[W`[BlancoCharacterGroup]Iɗp郊\[XohNXB]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 */
class BlancoCharacterGroupMessageResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoCharacterGroupMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoCharacterGroupMessage]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoCharacterGroupMessageResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/charactergroup/message/BlancoCharacterGroupMessage");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoCharacterGroupMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoCharacterGroupMessage]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoCharacterGroupMessageResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/charactergroup/message/BlancoCharacterGroupMessage", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoCharacterGroupMessageResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoCharacterGroupMessage]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoCharacterGroupMessageResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/charactergroup/message/BlancoCharacterGroupMessage", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BlancoCharacterGroupMessage], key[MBCHGI01]
     *
     * [O[v`ID[{0}]̃pbP[Ww肳Ă܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBCHGI01]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbchgi01(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "O[v`ID[{0}]̃pbP[Ww肳Ă܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBCHGI01");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoCharacterGroupMessage], key[MBCHGI02]
     *
     * [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBCHGI02]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbchgi02(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "T|[gȂo̓vO~Oꏈn[{0}]w肳܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBCHGI02");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoCharacterGroupMessage], key[MBCHGI03]
     *
     * [O[v`ID[{0}]ɂāA[{1}]2ȏ゠܂Bl2ȏwł܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @return key[MBCHGI03]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbchgi03(final String arg0, final String arg1) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "O[v`ID[{0}]ɂāA[{1}]2ȏ゠܂Bl2ȏwł܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBCHGI03");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoCharacterGroupMessage], key[MBCHGI04]
     *
     * [O[v`ID[{0}]ɂāA[{1}]w肳܂B{2}łBO[v`ł́A1Ŏw肷Kv܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @param arg1 u{1}ulBjava.lang.String^^ĂB
     * @param arg2 u{2}ulBjava.lang.String^^ĂB
     * @return key[MBCHGI04]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbchgi04(final String arg0, final String arg1, final String arg2) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "O[v`ID[{0}]ɂāA[{1}]w肳܂B{2}łBO[v`ł́A1Ŏw肷Kv܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBCHGI04");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0, arg1, arg2}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[BlancoCharacterGroupMessage], key[MBCHGA01]
     *
     * [^fBNg[{0}]݂܂B] (ja)<br>
     *
     * @param arg0 u{0}ulBjava.lang.String^^ĂB
     * @return key[MBCHGA01]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getMbchga01(final String arg0) {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "^fBNg[{0}]݂܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("MBCHGA01");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // ^ꂽɒuu܂B
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }
}
